@@ -3,6 +3,10 @@ from django.forms import forms
 
 class APICall(forms.Form):
 
+    def __init__(self, api_key=None, *args, **kwargs):
+        super(APICall, self).__init__(*args, **kwargs)
+        self.api_key = api_key
+
     def add_error(self, error_msg):
         errors = self.non_field_errors()
         errors.append(error_msg)
